pub struct ApiClientWithHostInformation {
pub client: Client,
pub host_information: Option<SignedHostInformation>,
}Expand description
A nym-node API client bundled with the node’s SignedHostInformation,
if it was retrieved during the connection/verification phase.
This avoids a redundant second call to the /host-information endpoint
when the caller also needs the host information after obtaining the client.
Fields
client: Clienthost_information: Option<SignedHostInformation>Trait Implementations