pub struct Client { /* private fields */ }Expand description
A simple extendable client wrapper for http request with extra url sanitization.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new_url<U>(
url: U,
timeout: Option<Duration>,
) -> Result<Client, HttpClientError>where
U: IntoUrl,
pub fn new_url<U>(
url: U,
timeout: Option<Duration>,
) -> Result<Client, HttpClientError>where
U: IntoUrl,
Attempt to create a new http client from a something that can be converted to a URL
Sourcepub fn builder<U>(url: U) -> Result<ClientBuilder, HttpClientError>where
U: IntoUrl,
pub fn builder<U>(url: U) -> Result<ClientBuilder, HttpClientError>where
U: IntoUrl,
Creates a ClientBuilder to configure a Client.
This is the same as ClientBuilder::new().
Sourcepub fn change_base_urls(&mut self, new_urls: Vec<Url>)
pub fn change_base_urls(&mut self, new_urls: Vec<Url>)
Update the set of hosts that this client uses when sending API requests.
Sourcepub fn clone_with_new_url(&self, new_url: Url) -> Client
pub fn clone_with_new_url(&self, new_url: Url) -> Client
Create new instance of Client using the provided base url and existing client config
Sourcepub fn current_url(&self) -> &Url
pub fn current_url(&self) -> &Url
Get the currently configured host that this client uses when sending API requests.
Sourcepub fn base_urls(&self) -> &[Url]
pub fn base_urls(&self) -> &[Url]
Get the currently configured host that this client uses when sending API requests.
Sourcepub fn base_urls_mut(&mut self) -> &mut [Url]
pub fn base_urls_mut(&mut self) -> &mut [Url]
Get a mutable reference to the hosts that this client uses when sending API requests.
Sourcepub fn change_retry_limit(&mut self, limit: usize)
pub fn change_retry_limit(&mut self, limit: usize)
Change the currently configured limit on the number of retries for a request.