pub struct ClientInterfaces {
pub wireguard: Option<Wireguard>,
pub mixnet_websockets: Option<WebSockets>,
}Fields
wireguard: Option<Wireguard>mixnet_websockets: Option<WebSockets>Trait Implementations
Sourceimpl Clone for ClientInterfaces
impl Clone for ClientInterfaces
Sourcefn clone(&self) -> ClientInterfaces
fn clone(&self) -> ClientInterfaces
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientInterfaces
impl Debug for ClientInterfaces
Sourceimpl<'de> Deserialize<'de> for ClientInterfaces
impl<'de> Deserialize<'de> for ClientInterfaces
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClientInterfaces
impl JsonSchema for ClientInterfaces
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ClientInterfaces
impl RefUnwindSafe for ClientInterfaces
impl Send for ClientInterfaces
impl Sync for ClientInterfaces
impl Unpin for ClientInterfaces
impl UnsafeUnpin for ClientInterfaces
impl UnwindSafe for ClientInterfaces