pub struct Wireguard {
pub port: u16,
pub tunnel_port: u16,
pub metadata_port: u16,
pub public_key: String,
}Fields
port: u16👎Deprecated:
use specific port instead (tunnel or metadata service)
tunnel_port: u16metadata_port: u16public_key: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Wireguard
impl<'de> Deserialize<'de> for Wireguard
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Wireguard
impl JsonSchema for Wireguard
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Wireguard
impl RefUnwindSafe for Wireguard
impl Send for Wireguard
impl Sync for Wireguard
impl Unpin for Wireguard
impl UnsafeUnpin for Wireguard
impl UnwindSafe for Wireguard