Module models

Module models 

Structs

AddressPolicy
A sequence of rules that are applied to an address:port until one matches.
AddressPolicyRule
A single rule in an address policy.
AddressPortPattern
A pattern that may or may not match an address and port.
PortRange
A PortRange is a set of consecutively numbered TCP or UDP ports.
UsedExitPolicy

Enums

AddressPolicyAction

Type Aliases

ExitPolicy