AddressPolicy

Struct AddressPolicy 

pub struct AddressPolicy { /* private fields */ }
A sequence of rules that are applied to an address:port until one matches.

Each rule is of the form “accept(6) PATTERN” or “reject(6) PATTERN”, where every pattern describes a set of addresses and ports. Address sets are given as a prefix of 0-128 bits that the address must have; port sets are given as a low-bound and high-bound that the target port might lie between.

An example IPv4 policy might be:

 reject *:25
 reject 127.0.0.0/8:*
 reject 192.168.0.0/16:*
 accept *:80
 accept *:443
 accept *:9000-65535
 reject *:*

Implementations

Source

impl AddressPolicy

pub const fn new() -> AddressPolicy

Create a new AddressPolicy that matches nothing.

pub fn new_open() -> AddressPolicy

Create a new AddressPolicy that matches everything.

pub fn is_open(&self) -> bool

Check whether this AddressPolicy matches all patterns.

pub fn parse_from_torrc<S>(raw: S) -> Result<AddressPolicy, PolicyError>
where S: AsRef<str>,

Attempts to parse the AddressPolicy out of raw torrc representation.

pub fn format_as_torrc(&self) -> String

Formats the AddressPolicy with torrc representation

pub fn allows(&self, addr: &IpAddr, port: u16) -> Option<bool>

Apply this policy to an address:port combination

We do this by applying each rule in sequence, until one matches.

Returns None if no rule matches.

pub fn allows_sockaddr(&self, addr: &SocketAddr) -> Option<bool>

As allows, but accept a SocketAddr.

pub fn push(&mut self, action: AddressPolicyAction, pattern: AddressPortPattern)

Add a new rule to this policy.

The newly added rule is applied after all previous rules. It matches all addresses and ports covered by AddressPortPattern.

If accept is true, the rule is to accept addresses that match; if accept is false, the rule rejects such addresses.

pub fn push_rule(&mut self, rule: AddressPolicyRule)

As push, but accepts a AddressPolicyRule.