pub struct UsedExitPolicy {
pub enabled: bool,
pub upstream_source: String,
pub last_updated: u64,
pub policy: Option<ExitPolicy>,
}Fields
enabled: boolFlag indicating whether this node uses the below exit policy or whether it still relies on the legacy allow lists.
upstream_source: StringSource URL from which the exit policy was obtained
last_updated: u64Unix timestamp indicating when the exit policy was last updated from the upstream.
policy: Option<ExitPolicy>The actual policy used by this node.