pub struct AnnouncePorts {
pub verloc_port: Option<u16>,
pub mix_port: Option<u16>,
}Fields
verloc_port: Option<u16>mix_port: Option<u16>Trait Implementations
Sourceimpl Clone for AnnouncePorts
impl Clone for AnnouncePorts
Sourcefn clone(&self) -> AnnouncePorts
fn clone(&self) -> AnnouncePorts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AnnouncePorts
Sourceimpl Debug for AnnouncePorts
impl Debug for AnnouncePorts
Sourceimpl Default for AnnouncePorts
impl Default for AnnouncePorts
Sourcefn default() -> AnnouncePorts
fn default() -> AnnouncePorts
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AnnouncePorts
impl<'de> Deserialize<'de> for AnnouncePorts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnnouncePorts
impl JsonSchema for AnnouncePorts
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AnnouncePorts
impl RefUnwindSafe for AnnouncePorts
impl Send for AnnouncePorts
impl Sync for AnnouncePorts
impl Unpin for AnnouncePorts
impl UnsafeUnpin for AnnouncePorts
impl UnwindSafe for AnnouncePorts