pub struct CryptoHardware {
pub aesni: bool,
pub avx2: bool,
pub smt_logical_processor_count: Vec<u32>,
pub osxsave: bool,
pub sgx: bool,
pub xsave: bool,
}Fields
aesni: boolFlag to indicate whether the host machine supports AES-NI x86 extension instruction set
avx2: boolFlag to indicate whether the host machine supports AVX2 x86 extension instruction set
smt_logical_processor_count: Vec<u32>Number of SMT logical processors available.
osxsave: boolFlag to indicate whether the host machine supports OSXSAVE instruction
sgx: boolFlag to indicate whether the host machine supports Intel Software Guard Extensions (SGX) set of instruction codes
xsave: boolFlag to indicate whether the host machine supports XSAVE instruction