pub struct HostKeys {
pub ed25519_identity: PublicKey,
pub x25519_sphinx: PublicKey,
pub primary_x25519_sphinx_key: SphinxKey,
pub pre_announced_x25519_sphinx_key: Option<SphinxKey>,
pub x25519_versioned_noise: Option<VersionedNoiseKey>,
}Fields
ed25519_identity: PublicKeyBase58-encoded ed25519 public key of this node. Currently, it corresponds to either mixnode’s or gateway’s identity.
x25519_sphinx: PublicKey👎Deprecated: use explicit primary_x25519_sphinx_key instead
primary_x25519_sphinx_key: SphinxKeyCurrent, active, x25519 sphinx key clients are expected to use when constructing packets with this node in the route.
pre_announced_x25519_sphinx_key: Option<SphinxKey>Pre-announced x25519 sphinx key clients will use during the following key rotation
x25519_versioned_noise: Option<VersionedNoiseKey>Base58-encoded x25519 public key of this node used for the noise protocol.