pub struct HostSystem {
pub system_name: Option<String>,
pub kernel_version: Option<String>,
pub os_version: Option<String>,
pub cpu_arch: Option<String>,
pub hardware: Option<Hardware>,
}Fields
system_name: Option<String>Name of the operating system of the host machine.
kernel_version: Option<String>Version of the kernel of the host machine, if applicable.
os_version: Option<String>Version of the operating system of the host machine, if applicable.
cpu_arch: Option<String>The CPU architecture of the host machine (eg. x86, amd64, aarch64, …).
hardware: Option<Hardware>Hardware information of the host machine.