pub struct BinaryBuildInformationOwned {
pub binary_name: String,
pub build_timestamp: String,
pub build_version: String,
pub commit_sha: String,
pub commit_timestamp: String,
pub commit_branch: String,
pub rustc_version: String,
pub rustc_channel: String,
pub cargo_profile: String,
pub cargo_triple: String,
}Fields
binary_name: StringProvides the name of the binary, i.e. the content of CARGO_PKG_NAME environmental variable.
build_timestamp: StringProvides the build timestamp, for example 2021-02-23T20:14:46.558472672+00:00.
build_version: StringProvides the build version, for example 0.1.0-9-g46f83e1.
commit_sha: StringProvides the hash of the commit that was used for the build, for example 46f83e112520533338245862d366f6a02cef07d4.
commit_timestamp: StringProvides the timestamp of the commit that was used for the build, for example 2021-02-23T08:08:02-05:00.
commit_branch: StringProvides the name of the git branch that was used for the build, for example master.
rustc_version: StringProvides the rustc version that was used for the build, for example 1.52.0-nightly.
rustc_channel: StringProvides the rustc channel that was used for the build, for example nightly.
cargo_profile: StringProvides the cargo debug mode that was used for the build.
cargo_triple: StringProvides the cargo target triple that was used for the build.